import { LoiDebit, ParallelStructure, StructureProperties, StructureType } from "jalhyd";
import { SelectField } from "./select-field";
import { SelectEntry } from "./select-entry";

/*
    "id": "select_loidebit",
    "type": "select",
    "property": "loiDebit",
    "source": "device_loi_debit",
    "help": {
*/

export class SelectFieldDeviceLoiDebit extends SelectField {
    protected populate() {
        // possible values depend on CalcType

        // get current structure type from appropriate Nub child
        const child = this.nub.getChildren()[this.parent.indexAsKid()];
        const la = (this.nub as ParallelStructure).getLoisAdmissibles();
        const loiDebit = child.properties.getPropValue("loiDebit");
        const stCode = StructureProperties.findCompatibleStructure(loiDebit, this.nub as ParallelStructure);
        const stName = StructureType[stCode];
        if (la[stName] !== undefined) {
            for (const ld of la[stName]) {
                const e: SelectEntry = new SelectEntry(this._entriesBaseId + LoiDebit[ld], ld);
                this.addEntry(e);
            }
        }
    }

    protected initSelectedValue() {
        this.findAndSetDefaultValue();
    }

    public get associatedProperty(): string {
        return "loiDebit";
    }

    public get configDefaultValue(): string {
        return undefined;
    }
}