/*
"type": "select_custom",
"id": "select_species_list",
"source": "verificateur_species",
"multiple": true
*/

import { ServiceFactory } from "app/services/service-factory";
import { CalculatorType, FishSpecies, Session, Verificateur } from "jalhyd";
import { sprintf } from "sprintf-js";
import { FormulaireNode } from "../formulaire-node";
import { SelectEntry } from "./select-entry";
import { SelectField } from "./select-field";

// Vérificateur, liste d'espèces (choix multiple)
export class SelectFieldSpeciesList extends SelectField {
    constructor(parent: FormulaireNode) {
        super(parent);
        this._multiple = true;
    }

    protected populate() {
        // add UIDs of all Espece type Nubs in the session
        const especeNubs = Session.getInstance().getAllNubs().filter((element) => element.calcType === CalculatorType.Espece);
        for (const en of especeNubs) {
            const form = ServiceFactory.formulaireService.getFormulaireFromNubId(en.uid);
            this.addEntry(
                new SelectEntry(
                    this._entriesBaseId + en.uid,
                    en.uid,
                    sprintf(
                        ServiceFactory.i18nService.localizeText("INFO_VERIFICATEUR_CUSTOM_SPECIES"),
                        form ? form.calculatorName : "*** form not loaded yet ***"
                    )
                )
            );
        }
        // add all FishSpecies
        for (let j = 1; j < Object.keys(FishSpecies).length / 2; j++) { // exclude "0" (SPECIES_CUSTOM)
            const spgId = FishSpecies[j].substring(FishSpecies[j].lastIndexOf("_") + 1);
            this.addEntry(
                new SelectEntry(
                    this._entriesBaseId + spgId,
                    FishSpecies[j],
                    ServiceFactory.i18nService.localizeText("INFO_ENUM_" + FishSpecies[j])
                )
            );
        }
    }

    protected initSelectedValue() {
        const sl = (this.nub as Verificateur).speciesList;
        if (sl !== undefined) {
            this.setValueFromId(sl.map((s) => {
                const spgId = s.substring(s.lastIndexOf("_") + 1);
                return this._entriesBaseId + spgId;
            }));
        }
    }

    public get associatedProperty(): string {
        return undefined;
    }

    public get configDefaultValue(): string {
        return undefined;
    }

    public updateLocalisation() {
        // do not override localisation done in populate()
        // ie. avoid what is done by SelectField.updateLocalisation()
    }
}